ParserConfig

Struct ParserConfig 

pub struct ParserConfig {
    pub allow_wrong_line_comments: bool,
    pub css_modules: bool,
    pub legacy_nesting: bool,
    pub legacy_ie: bool,
}

Fields

allow_wrong_line_comments: bool

If this is true, wrong comments starting with // will be treated as a comment.

This option exists because there are so many css-in-js tools and people use // as a comment because it’s javascript file.

Defaults to false.

css_modules: bool

If enabled, errors for css modules selectors will be ignored.

Defaults to false.

legacy_nesting: bool

If this is true, the nested selector starts with an identifier will be parsed as valid selectors (i.e. ul { color: red; li { color: blue } })

Defaults to false.

legacy_ie: bool

If this is true, the legacy syntax for IE will be parsed.